@@ -614,7 +614,7 @@ public class StatisticTools extends AbstractJMXTools {
         return getStats(con, "com.openexchange.admin.monitor:name=CallMonitor");
     }
 
-    private static String showCacheData(MBeanServerConnection mbc) throws MalformedObjectNameException, InstanceNotFoundException, NullPointerException, MBeanException, ReflectionException, IOException, InvalidDataException {
+    private static String showCacheData(MBeanServerConnection mbc) throws NullPointerException, IOException, InvalidDataException, IllegalStateException, JMException {
         StringBuilder sb = new StringBuilder();
         sb.append(doOperationReturnString(mbc, "com.openexchange.caching:name=JCSCacheInformation!getMemoryCacheCount!Context"));
         sb.append(doOperationReturnString(mbc, "com.openexchange.caching:name=JCSCacheInformation!getMemoryCacheCount!Filestore"));
@@ -630,9 +630,10 @@ public class StatisticTools extends AbstractJMXTools {
         sb.append(doOperationReturnString(mbc, "com.openexchange.caching:name=JCSCacheInformation!getMemoryCacheCount!MailConnectionCache"));
         sb.append(doOperationReturnString(mbc, "com.openexchange.caching:name=JCSCacheInformation!getMemoryCacheCount!CalendarCache"));
         sb.append(doOperationReturnString(mbc, "com.openexchange.caching:name=JCSCacheInformation!getMemoryCacheCount!SessionCache"));
+        sb.append(getStats(mbc, "com.openexchange.caching", "name", "CacheEventInformation"));
         return sb.toString();
     }
-    
+
     static String showThreadPoolData(final MBeanServerConnection mbc) throws InstanceNotFoundException, AttributeNotFoundException, IntrospectionException, MBeanException, ReflectionException, IOException, MalformedObjectNameException, NullPointerException {
         return getStats(mbc, "com.openexchange.threadpool:name=ThreadPoolInformation").toString();
     }
@@ -656,10 +657,12 @@ public class StatisticTools extends AbstractJMXTools {
     }
 
     static String showClusterData(MBeanServerConnection mbc) throws MalformedObjectNameException, NullPointerException, IOException, InstanceNotFoundException, IntrospectionException, ReflectionException, AttributeNotFoundException, MBeanException {
-        // general info
+        /*
+         * query general information
+         */
         StringBuilder sb = new StringBuilder();
-        for (String type : new String[] { "HazelcastInstance", "HazelcastInstance.Node",
-            "HazelcastInstance.ClientEngine", "HazelcastInstance.ConnectionManager" }) {
+        for (String type : new String[] { "HazelcastInstance", "HazelcastInstance.Node", "HazelcastInstance.EventService",
+            "HazelcastInstance.ClientEngine", "HazelcastInstance.ConnectionManager", "HazelcastInstance.PartitionServiceMBean" }) {
             for (ObjectInstance mbean : mbc.queryMBeans(new ObjectName("com.hazelcast:type=" + type + ",*"), null)) {
                 ObjectName objectName = mbean.getObjectName();
                 MBeanInfo beanInfo = mbc.getMBeanInfo(objectName);
@@ -695,24 +698,43 @@ public class StatisticTools extends AbstractJMXTools {
                 }
             }
         }
-        // maps
+        /*
+         * probe if detailed map statistics are available
+         */
+        ObjectName toolkitName = new ObjectName("com.openexchange.hazelcast", "name", "Hazelcast Toolkit");
+        Set<ObjectInstance> mBeans = mbc.queryMBeans(toolkitName, null);
+        if (null == mBeans || 0 == mBeans.size()) {
+            return sb.append("[Hazelcast Toolkit MBean not available, unable to retrieve map statistics]").append(LINE_SEPARATOR).toString();
+        }
+        if (null == mbc.invoke(toolkitName, "getPartitionOwner", new Object[] { "probe" }, new String[] { String.class.getName() })) {
+            return sb.append("[No partition owners detected, unable to retrieve map statistics]").append(LINE_SEPARATOR).toString();
+        }
+        Object result = mbc.invoke(toolkitName, "usesCustomPartitioning", new Object[0], new String[0]);
+        if (null == result || false == Boolean.class.isInstance(result) || Boolean.TRUE.equals(result)) {
+            result = mbc.invoke(toolkitName, "supportsPartitionReplicas", new Object[0], new String[0]);
+            if (null == result || false == Boolean.class.isInstance(result) || Boolean.FALSE.equals(result)) {
+                return sb.append("[No owner for all configured partition replicas detected, unable to retrieve map statistics]")
+                   .append(LINE_SEPARATOR).toString();
+            }
+        }
+        /*
+         * query map statistics
+         */
         for (String type : new String[] { "IMap", "IMultiMap", "ITopic", "IQueue" }) {
             for (ObjectInstance mbean : mbc.queryMBeans(new ObjectName("com.hazelcast:type=" + type + ",instance=*,name=*"), null)) {
                 ObjectName objectName = mbean.getObjectName();
                 MBeanInfo beanInfo = mbc.getMBeanInfo(objectName);
                 for (MBeanAttributeInfo attributeInfo : beanInfo.getAttributes()) {
-                    sb.append(objectName);
-                    sb.append(',');
-                    sb.append(attributeInfo.getName());
-                    sb.append(" = ");
-                    try {
-                        sb.append(mbc.getAttribute(objectName, attributeInfo.getName()));
-                    } catch (Exception e) {
-                        sb.append('[');
-                        sb.append(e.getMessage());
-                        sb.append(']');
+                    String name = attributeInfo.getName();
+                    if (null != name && ("config".equals(name) || name.startsWith("local"))) {
+                        sb.append(objectName).append(',').append(name).append(" = ");
+                        try {
+                            sb.append(mbc.getAttribute(objectName, name));
+                        } catch (Exception e) {
+                            sb.append('[').append(e.getMessage()).append(']');
+                        }
+                        sb.append(LINE_SEPARATOR);
                     }
-                    sb.append(LINE_SEPARATOR);
                 }
             }
         }
