@@ -64,6 +64,7 @@ import com.openexchange.caching.CacheService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.context.ContextService;
 import com.openexchange.database.DatabaseService;
+import com.openexchange.groupware.filestore.FilestoreLocationUpdater;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.management.ManagementService;
 import com.openexchange.osgi.HousekeepingActivator;
@@ -115,6 +116,8 @@ public class Activator extends HousekeepingActivator {
             PluginInterfaces.setInstance(builder.build());
         }
 
+        track(FilestoreLocationUpdater.class, new FilestoreLocationUpdaterCustomizer(context));
+
         // Open trackers
         openTrackers();
 
