@@ -101,7 +101,6 @@ import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
-import com.openexchange.quota.Resource;
 import com.openexchange.tools.pipesnfilters.Filter;
 
 public class OXContext extends OXContextCommonImpl implements OXContextInterface {
@@ -121,21 +120,11 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         if (isEmpty(sModule)) {
             throw new InvalidDataException("No valid module specified.");
         }
-        final Set<String> modules;
-        {
-            final Resource[] resources = Resource.values();
-            final String[] mods = sModule.split(" *, *");
-            modules = new LinkedHashSet<String>(mods.length);
-            for (final String mod : mods) {
-                boolean found = false;
-                for (int i = 0; !found && i < resources.length; i++) {
-                    found = resources[i].getIdentifier().equalsIgnoreCase(mod);
-                }
-                if (!found) {
-                    throw new InvalidDataException("Unknown module: \"" + mod + "\" (known modules: " + Arrays.toString(Resource.allIdentifiers()) + ")");
-                }
-                modules.add(mod);
-            }
+
+        final String[] mods = sModule.split(" *, *");
+        final Set<String> modules = new LinkedHashSet<String>(mods.length);
+        for (final String mod : mods) {
+            modules.add(mod);
         }
 
         final Credentials auth = credentials == null ? new Credentials("", "") : credentials;
@@ -1033,6 +1022,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             retval = oxcox.getData(ctx);
 
             final int srcStore_id = retval.getFilestoreId().intValue();
+            ctx.setFilestoreId(srcStore_id);
             if (srcStore_id == dst_filestore.getId().intValue()) {
                 throw new OXContextException("Src and dst store id is the same: " + dst_filestore);
             }
@@ -1051,9 +1041,6 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 final Filestore srcfilestore = oxu.getFilestore(srcStore_id);
                 URI sourceURI = new URI(srcfilestore.getUrl());
                 URI destURI = new URI(destFilestore.getUrl());
-                if (false == "file".equalsIgnoreCase(sourceURI.getScheme()) || false == "file".equalsIgnoreCase(destURI.getScheme())) {
-                    throw new StorageException("Only \"file\" filestores are currently supported.");
-                }
                 final StringBuilder src = builduppath(ctxdir, sourceURI);
                 final String dst = destURI.getPath();
                 final OXContextException contextException = new OXContextException("Unable to move filestore");
@@ -1064,7 +1051,13 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                     LOGGER.error("dst is null");
                     throw contextException;
                 }
-                final FilestoreDataMover fsdm = new FilestoreDataMover(src.toString(), dst.toString(), ctx, dst_filestore);
+                FilestoreDataMover fsdm = null;
+                boolean rsyncEnabled = "file".equalsIgnoreCase(sourceURI.getScheme()) && "file".equalsIgnoreCase(destURI.getScheme());
+                if (rsyncEnabled) {
+                    fsdm = new FilestoreDataMover(src.toString(), dst.toString(), ctx, dst_filestore, true);
+                } else {
+                    fsdm = new FilestoreDataMover(sourceURI.toString() + "/" + ctxdir, destURI.toString(), ctx, dst_filestore, false);
+                }
                 return TaskManager.getInstance().addJob(fsdm, "movefilestore", "move context " + ctx.getIdAsString() + " to filestore " + dst_filestore.getId(), ctx.getId());
             } catch (final StorageException e) {
                 throw new OXContextException(e);
@@ -1078,9 +1071,6 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         } catch (final NoSuchFilestoreException e) {
             LOGGER.error("", e);
             throw e;
-        /*} catch (final NoSuchReasonException e) {
-            log.error("", e);
-            throw e;*/
         } catch (final OXContextException e) {
             LOGGER.error("", e);
             throw e;
@@ -1149,7 +1139,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
 
     private StringBuilder builduppath(final String ctxdir, final URI uri) {
         final StringBuilder src = new StringBuilder(uri.getPath());
-        if (src.charAt(src.length()-1) != '/') {
+        if (src.length() == 0 || src.charAt(src.length()-1) != '/') {
             src.append('/');
         }
         src.append(ctxdir);
